# -*- coding: utf-8 -*-
from .vocab import Vocab

__all__ = ["Vocab"]
